@@ -2,10 +2,10 @@ from __future__ import annotations
 import os
 import logging
 from typing import Optional
-from serverless_sdk import serverlessSdk as baseSdk
+from sls_sdk import serverlessSdk as baseSdk
 from .trace_spans.aws_lambda import aws_lambda_span
-from serverless_sdk import ServerlessSdk, TraceSpans
-from serverless_sdk.lib.trace import TraceSpan
+from sls_sdk import ServerlessSdk, TraceSpans
+from sls_sdk.lib.trace import TraceSpan
 from .base import NAME, __version__
 
 
